# Changelog

## 0.2.0 (01-01-2022)

- GH-7: Use `settings.CONF_ROOT` to look up catalog entry definition.
- Add a small script to launch a TCP development server for easier debugging.

## 0.1.1 (15-06-2021)

- GH-1: Fix line number parsing for parameters, which allows Goto Definition to work for parameters

## 0.1.0 (13-06-2021)

- Initial release
